Class: Azure::Subscriptions::Mgmt::V2017_11_01_preview::SubscriptionDefinitions

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb

Overview

Subscription definitions client provides an interface to create, modify and retrieve azure subscriptions programmatically.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ SubscriptionDefinitions

Creates and initializes a new instance of the SubscriptionDefinitions class.

Parameters:

  • client

    service class for accessing basic functionality.



18
19
20
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientSubscriptionDefinitionsClient (readonly)

Returns reference to the SubscriptionDefinitionsClient.

Returns:



23
24
25
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 23

def client
  @client
end

Instance Method Details

#begin_create(subscription_definition_name, body, custom_headers: nil) ⇒ SubscriptionDefinition

Create an Azure subscription definition.

subscription definition. will be added to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • body (SubscriptionDefinition)

    The subscription definition creation.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionDefinition)

    operation results.



351
352
353
354
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 351

def begin_create(subscription_definition_name, body, custom_headers:nil)
  response = begin_create_async(subscription_definition_name, body, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#begin_create_async(subscription_definition_name, body, custom_headers: nil) ⇒ Concurrent::Promise

Create an Azure subscription definition.

subscription definition. to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • body (SubscriptionDefinition)

    The subscription definition creation.

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 382

def begin_create_async(subscription_definition_name, body, custom_headers:nil)
  fail ArgumentError, 'subscription_definition_name is nil' if subscription_definition_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'body is nil' if body.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinition.mapper()
  request_content = @client.serialize(request_mapper,  body)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'providers/Microsoft.Subscription/subscriptionDefinitions/{subscriptionDefinitionName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionDefinitionName' => subscription_definition_name},
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:put, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinition.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#begin_create_with_http_info(subscription_definition_name, body, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Create an Azure subscription definition.

subscription definition. will be added to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • body (SubscriptionDefinition)

    The subscription definition creation.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



367
368
369
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 367

def begin_create_with_http_info(subscription_definition_name, body, custom_headers:nil)
  begin_create_async(subscription_definition_name, body, custom_headers:custom_headers).value!
end

#create(subscription_definition_name, body, custom_headers: nil) ⇒ SubscriptionDefinition

Create an Azure subscription definition.

subscription definition. will be added to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • body (SubscriptionDefinition)

    The subscription definition creation.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionDefinition)

    operation results.



36
37
38
39
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 36

def create(subscription_definition_name, body, custom_headers:nil)
  response = create_async(subscription_definition_name, body, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#create_async(subscription_definition_name, body, custom_headers: nil) ⇒ Concurrent::Promise

subscription definition. will be added to the HTTP request.

response.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • body (SubscriptionDefinition)

    The subscription definition creation.

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 51

def create_async(subscription_definition_name, body, custom_headers:nil)
  # Send request
  promise = begin_create_async(subscription_definition_name, body, custom_headers:custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
      result_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinition.mapper()
      parsed_response = @client.deserialize(result_mapper, parsed_response)
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end

#get(subscription_definition_name, custom_headers: nil) ⇒ SubscriptionDefinition

Get an Azure subscription definition.

subscription definition. will be added to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionDefinition)

    operation results.



79
80
81
82
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 79

def get(subscription_definition_name, custom_headers:nil)
  response = get_async(subscription_definition_name, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_async(subscription_definition_name, custom_headers: nil) ⇒ Concurrent::Promise

Get an Azure subscription definition.

subscription definition. to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 108

def get_async(subscription_definition_name, custom_headers:nil)
  fail ArgumentError, 'subscription_definition_name is nil' if subscription_definition_name.nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'providers/Microsoft.Subscription/subscriptionDefinitions/{subscriptionDefinitionName}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'subscriptionDefinitionName' => subscription_definition_name},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinition.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_operation_status(operation_id, custom_headers: nil) ⇒ SubscriptionDefinition

Retrieves the status of the subscription definition PUT operation. The URI of this API is returned in the Location field of the response header.

field in the generate recommendation response header. will be added to the HTTP request.

Parameters:

  • operation_id

    The operation ID, which can be found from the Location

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionDefinition)

    operation results.



256
257
258
259
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 256

def get_operation_status(operation_id, custom_headers:nil)
  response = get_operation_status_async(operation_id, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#get_operation_status_async(operation_id, custom_headers: nil) ⇒ Concurrent::Promise

Retrieves the status of the subscription definition PUT operation. The URI of this API is returned in the Location field of the response header.

field in the generate recommendation response header. to the HTTP request.

Parameters:

  • operation_id

    The operation ID, which can be found from the Location

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 287

def get_operation_status_async(operation_id, custom_headers:nil)
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'operation_id is nil' if operation_id.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'providers/Microsoft.Subscription/subscriptionOperations/{operationId}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'operationId' => operation_id},
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 202 || status_code == 200
      error_model = JSON.load(response_content)
      fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinition.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#get_operation_status_with_http_info(operation_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Retrieves the status of the subscription definition PUT operation. The URI of this API is returned in the Location field of the response header.

field in the generate recommendation response header. will be added to the HTTP request.

Parameters:

  • operation_id

    The operation ID, which can be found from the Location

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



272
273
274
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 272

def get_operation_status_with_http_info(operation_id, custom_headers:nil)
  get_operation_status_async(operation_id, custom_headers:custom_headers).value!
end

#get_with_http_info(subscription_definition_name, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Get an Azure subscription definition.

subscription definition. will be added to the HTTP request.

Parameters:

  • subscription_definition_name (String)

    The name of the Azure

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



94
95
96
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 94

def get_with_http_info(subscription_definition_name, custom_headers:nil)
  get_async(subscription_definition_name, custom_headers:custom_headers).value!
end

#list(custom_headers: nil) ⇒ Array<SubscriptionDefinition>

List an Azure subscription definition by subscriptionId.

will be added to the HTTP request.

Parameters:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Array<SubscriptionDefinition>)

    operation results.



169
170
171
172
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 169

def list(custom_headers:nil)
  first_page = list_as_lazy(custom_headers:custom_headers)
  first_page.get_all_items
end

#list_as_lazy(custom_headers: nil) ⇒ SubscriptionDefinitionList

List an Azure subscription definition by subscriptionId.

will be added to the HTTP request.

the response.

Parameters:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionDefinitionList)

    which provide lazy access to pages of



542
543
544
545
546
547
548
549
550
551
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 542

def list_as_lazy(custom_headers:nil)
  response = list_async(custom_headers:custom_headers).value!
  unless response.nil?
    page = response.body
    page.next_method = Proc.new do |next_page_link|
      list_next_async(next_page_link, custom_headers:custom_headers)
    end
    page
  end
end

#list_async(custom_headers: nil) ⇒ Concurrent::Promise

List an Azure subscription definition by subscriptionId.

to the HTTP request.

Parameters:

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 194

def list_async(custom_headers:nil)
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = 'providers/Microsoft.Subscription/subscriptionDefinitions'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      query_params: {'api-version' => @client.api_version},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinitionList.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next(next_page_link, custom_headers: nil) ⇒ SubscriptionDefinitionList

List an Azure subscription definition by subscriptionId.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionDefinitionList)

    operation results.



453
454
455
456
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 453

def list_next(next_page_link, custom_headers:nil)
  response = list_next_async(next_page_link, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#list_next_async(next_page_link, custom_headers: nil) ⇒ Concurrent::Promise

List an Azure subscription definition by subscriptionId.

to List operation. to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 482

def list_next_async(next_page_link, custom_headers:nil)
  fail ArgumentError, 'next_page_link is nil' if next_page_link.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
  path_template = '{nextLink}'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      skip_encoding_path_params: {'nextLink' => next_page_link},
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:get, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Subscriptions::Mgmt::V2017_11_01_preview::Models::SubscriptionDefinitionList.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#list_next_with_http_info(next_page_link, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

List an Azure subscription definition by subscriptionId.

to List operation. will be added to the HTTP request.

Parameters:

  • next_page_link (String)

    The NextLink from the previous successful call

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



468
469
470
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 468

def list_next_with_http_info(next_page_link, custom_headers:nil)
  list_next_async(next_page_link, custom_headers:custom_headers).value!
end

#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

List an Azure subscription definition by subscriptionId.

will be added to the HTTP request.

Parameters:

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



182
183
184
# File 'lib/2017-11-01-preview/generated/azure_mgmt_subscriptions/subscription_definitions.rb', line 182

def list_with_http_info(custom_headers:nil)
  list_async(custom_headers:custom_headers).value!
end