Class: Azure::Subscriptions::Mgmt::V2018_03_01_preview::SubscriptionFactory

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb

Overview

Subscription client provides an interface to create and manage Azure subscriptions programmatically.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ SubscriptionFactory

Creates and initializes a new instance of the SubscriptionFactory class.

Parameters:

  • client

    service class for accessing basic functionality.



18
19
20
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 18

def initialize(client)
  @client = client
end

Instance Attribute Details

#clientSubscriptionClient (readonly)

Returns reference to the SubscriptionClient.

Returns:



23
24
25
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 23

def client
  @client
end

Instance Method Details

#begin_create_subscription_in_enrollment_account(enrollment_account_name, body, custom_headers: nil) ⇒ SubscriptionCreationResult

Creates an Azure subscription

which the subscription will be billed. parameters. will be added to the HTTP request.

Parameters:

  • enrollment_account_name (String)

    The name of the enrollment account to

  • body (SubscriptionCreationParameters)

    The subscription creation

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionCreationResult)

    operation results.



83
84
85
86
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 83

def (, body, custom_headers:nil)
  response = (, body, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#begin_create_subscription_in_enrollment_account_async(enrollment_account_name, body, custom_headers: nil) ⇒ Concurrent::Promise

Creates an Azure subscription

which the subscription will be billed. parameters. to the HTTP request.

Parameters:

  • enrollment_account_name (String)

    The name of the enrollment account to

  • body (SubscriptionCreationParameters)

    The subscription creation

  • A (Hash{String => String})

    hash of custom headers that will be added

Returns:

  • (Concurrent::Promise)

    Promise object which holds the HTTP response.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 116

def (, body, custom_headers:nil)
  fail ArgumentError, 'enrollment_account_name is nil' if .nil?
  fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?
  fail ArgumentError, 'body is nil' if body.nil?


  request_headers = {}
  request_headers['Content-Type'] = 'application/json; charset=utf-8'

  # Set Headers
  request_headers['x-ms-client-request-id'] = SecureRandom.uuid
  request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?

  # Serialize Request
  request_mapper = Azure::Subscriptions::Mgmt::V2018_03_01_preview::Models::SubscriptionCreationParameters.mapper()
  request_content = @client.serialize(request_mapper,  body)
  request_content = request_content != nil ? JSON.generate(request_content, quirks_mode: true) : nil

  path_template = 'providers/Microsoft.Billing/enrollmentAccounts/{enrollmentAccountName}/providers/Microsoft.Subscription/createSubscription'

  request_url = @base_url || @client.base_url

  options = {
      middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
      path_params: {'enrollmentAccountName' => },
      query_params: {'api-version' => @client.api_version},
      body: request_content,
      headers: request_headers.merge(custom_headers || {}),
      base_url: request_url
  }
  promise = @client.make_request_async(:post, path_template, options)

  promise = promise.then do |result|
    http_response = result.response
    status_code = http_response.status
    response_content = http_response.body
    unless status_code == 200 || status_code == 202
      error_model = JSON.load(response_content)
      fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
    end

    result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
    result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
    result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
    # Deserialize Response
    if status_code == 200
      begin
        parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
        result_mapper = Azure::Subscriptions::Mgmt::V2018_03_01_preview::Models::SubscriptionCreationResult.mapper()
        result.body = @client.deserialize(result_mapper, parsed_response)
      rescue Exception => e
        fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
      end
    end

    result
  end

  promise.execute
end

#begin_create_subscription_in_enrollment_account_with_http_info(enrollment_account_name, body, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse

Creates an Azure subscription

which the subscription will be billed. parameters. will be added to the HTTP request.

Parameters:

  • enrollment_account_name (String)

    The name of the enrollment account to

  • body (SubscriptionCreationParameters)

    The subscription creation

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (MsRestAzure::AzureOperationResponse)

    HTTP response information.



100
101
102
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 100

def (, body, custom_headers:nil)
  (, body, custom_headers:custom_headers).value!
end

#create_subscription_in_enrollment_account(enrollment_account_name, body, custom_headers: nil) ⇒ SubscriptionCreationResult

Creates an Azure subscription

which the subscription will be billed. parameters. will be added to the HTTP request.

Parameters:

  • enrollment_account_name (String)

    The name of the enrollment account to

  • body (SubscriptionCreationParameters)

    The subscription creation

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (SubscriptionCreationResult)

    operation results.



37
38
39
40
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 37

def (, body, custom_headers:nil)
  response = (, body, custom_headers:custom_headers).value!
  response.body unless response.nil?
end

#create_subscription_in_enrollment_account_async(enrollment_account_name, body, custom_headers: nil) ⇒ Concurrent::Promise

which the subscription will be billed. parameters. will be added to the HTTP request.

response.

Parameters:

  • enrollment_account_name (String)

    The name of the enrollment account to

  • body (SubscriptionCreationParameters)

    The subscription creation

  • custom_headers (Hash{String => String}) (defaults to: nil)

    A hash of custom headers that

Returns:

  • (Concurrent::Promise)

    promise which provides async access to http



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_factory.rb', line 53

def (, body, custom_headers:nil)
  # Send request
  promise = (, body, custom_headers:custom_headers)

  promise = promise.then do |response|
    # Defining deserialization method.
    deserialize_method = lambda do |parsed_response|
      result_mapper = Azure::Subscriptions::Mgmt::V2018_03_01_preview::Models::SubscriptionCreationResult.mapper()
      parsed_response = @client.deserialize(result_mapper, parsed_response)
    end

    # Waiting for response.
    @client.get_long_running_operation_result(response, deserialize_method)
  end

  promise
end