Class: Azure::Subscriptions::Mgmt::V2018_03_01_preview::SubscriptionOperations
- Inherits:
-
Object
- Object
- Azure::Subscriptions::Mgmt::V2018_03_01_preview::SubscriptionOperations
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_operations.rb
Overview
Subscription client provides an interface to create and manage Azure subscriptions programmatically.
Instance Attribute Summary collapse
-
#client ⇒ SubscriptionClient
readonly
Reference to the SubscriptionClient.
Instance Method Summary collapse
-
#initialize(client) ⇒ SubscriptionOperations
constructor
Creates and initializes a new instance of the SubscriptionOperations class.
-
#list(custom_headers: nil) ⇒ SubscriptionOperationListResult
Lists all of the available pending Microsoft.Subscription API operations.
-
#list_async(custom_headers: nil) ⇒ Concurrent::Promise
Lists all of the available pending Microsoft.Subscription API operations.
-
#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Lists all of the available pending Microsoft.Subscription API operations.
Constructor Details
#initialize(client) ⇒ SubscriptionOperations
Creates and initializes a new instance of the SubscriptionOperations class.
18 19 20 |
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_operations.rb', line 18 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ SubscriptionClient (readonly)
Returns reference to the SubscriptionClient.
23 24 25 |
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_operations.rb', line 23 def client @client end |
Instance Method Details
#list(custom_headers: nil) ⇒ SubscriptionOperationListResult
Lists all of the available pending Microsoft.Subscription API operations.
will be added to the HTTP request.
33 34 35 36 |
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_operations.rb', line 33 def list(custom_headers:nil) response = list_async(custom_headers:custom_headers).value! response.body unless response.nil? end |
#list_async(custom_headers: nil) ⇒ Concurrent::Promise
Lists all of the available pending Microsoft.Subscription API operations.
to the HTTP request.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_operations.rb', line 58 def list_async(custom_headers:nil) fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'providers/Microsoft.Subscription/subscriptionOperations' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 error_model = JSON.load(response_content) fail MsRest::HttpOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Subscriptions::Mgmt::V2018_03_01_preview::Models::SubscriptionOperationListResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#list_with_http_info(custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Lists all of the available pending Microsoft.Subscription API operations.
will be added to the HTTP request.
46 47 48 |
# File 'lib/2018-03-01-preview/generated/azure_mgmt_subscriptions/subscription_operations.rb', line 46 def list_with_http_info(custom_headers:nil) list_async(custom_headers:custom_headers).value! end |