Class: Azure::Subscriptions::Mgmt::V2018_11_01_preview::SubscriptionOperationOperations
- Inherits:
-
Object
- Object
- Azure::Subscriptions::Mgmt::V2018_11_01_preview::SubscriptionOperationOperations
- Includes:
- MsRestAzure
- Defined in:
- lib/2018-11-01-preview/generated/azure_mgmt_subscriptions/subscription_operation_operations.rb
Overview
Subscription client provides an interface to create and manage Azure subscriptions programmatically.
Instance Attribute Summary collapse
-
#client ⇒ SubscriptionClient
readonly
Reference to the SubscriptionClient.
Instance Method Summary collapse
-
#get(operation_id, custom_headers: nil) ⇒ SubscriptionCreationResult
Get the status of the pending Microsoft.Subscription API operations.
-
#get_async(operation_id, custom_headers: nil) ⇒ Concurrent::Promise
Get the status of the pending Microsoft.Subscription API operations.
-
#get_with_http_info(operation_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get the status of the pending Microsoft.Subscription API operations.
-
#initialize(client) ⇒ SubscriptionOperationOperations
constructor
Creates and initializes a new instance of the SubscriptionOperationOperations class.
Constructor Details
#initialize(client) ⇒ SubscriptionOperationOperations
Creates and initializes a new instance of the SubscriptionOperationOperations class.
18 19 20 |
# File 'lib/2018-11-01-preview/generated/azure_mgmt_subscriptions/subscription_operation_operations.rb', line 18 def initialize(client) @client = client end |
Instance Attribute Details
#client ⇒ SubscriptionClient (readonly)
Returns reference to the SubscriptionClient.
23 24 25 |
# File 'lib/2018-11-01-preview/generated/azure_mgmt_subscriptions/subscription_operation_operations.rb', line 23 def client @client end |
Instance Method Details
#get(operation_id, custom_headers: nil) ⇒ SubscriptionCreationResult
Get the status of the pending Microsoft.Subscription API operations.
Location field in the generate recommendation response header. will be added to the HTTP request.
35 36 37 38 |
# File 'lib/2018-11-01-preview/generated/azure_mgmt_subscriptions/subscription_operation_operations.rb', line 35 def get(operation_id, custom_headers:nil) response = get_async(operation_id, custom_headers:custom_headers).value! response.body unless response.nil? end |
#get_async(operation_id, custom_headers: nil) ⇒ Concurrent::Promise
Get the status of the pending Microsoft.Subscription API operations.
Location field in the generate recommendation response header. to the HTTP request.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/2018-11-01-preview/generated/azure_mgmt_subscriptions/subscription_operation_operations.rb', line 64 def get_async(operation_id, custom_headers:nil) fail ArgumentError, 'operation_id is nil' if operation_id.nil? fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil? request_headers = {} request_headers['Content-Type'] = 'application/json; charset=utf-8' # Set Headers request_headers['x-ms-client-request-id'] = SecureRandom.uuid request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil? path_template = 'providers/Microsoft.Subscription/subscriptionOperations/{operationId}' request_url = @base_url || @client.base_url = { middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]], path_params: {'operationId' => operation_id}, query_params: {'api-version' => @client.api_version}, headers: request_headers.merge(custom_headers || {}), base_url: request_url } promise = @client.make_request_async(:get, path_template, ) promise = promise.then do |result| http_response = result.response status_code = http_response.status response_content = http_response.body unless status_code == 200 || status_code == 202 error_model = JSON.load(response_content) fail MsRestAzure::AzureOperationError.new(result.request, http_response, error_model) end result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil? result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil? result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil? # Deserialize Response if status_code == 200 begin parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content) result_mapper = Azure::Subscriptions::Mgmt::V2018_11_01_preview::Models::SubscriptionCreationResult.mapper() result.body = @client.deserialize(result_mapper, parsed_response) rescue Exception => e fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e., e.backtrace, result) end end result end promise.execute end |
#get_with_http_info(operation_id, custom_headers: nil) ⇒ MsRestAzure::AzureOperationResponse
Get the status of the pending Microsoft.Subscription API operations.
Location field in the generate recommendation response header. will be added to the HTTP request.
50 51 52 |
# File 'lib/2018-11-01-preview/generated/azure_mgmt_subscriptions/subscription_operation_operations.rb', line 50 def get_with_http_info(operation_id, custom_headers:nil) get_async(operation_id, custom_headers:custom_headers).value! end |